Crate brush_core

Crate brush_core 

Core implementation of the brush shell. Implements the shell’s abstraction, its interpreter, and various facilities used internally by the shell.

Re-exports

pub use commands::CommandArg;
pub use commands::ExecutionContext;
pub use error::BuiltinError;
pub use error::Error;
pub use error::ErrorKind;
pub use extensions::ShellExtensions;
pub use results::ExecutionControlFlow;
pub use results::ExecutionExitCode;
pub use results::ExecutionResult;
pub use results::ExecutionSpawnResult;
pub use sourceinfo::SourceInfo;
pub use variables::ShellValue;
pub use variables::ShellVariable;

Modules

arithmetic
Arithmetic evaluation
builtins
Facilities for implementing and managing builtins
callstack
Call stack representations.
commands
Command execution
completion
Implements programmable command completion support.
env
Implements a shell variable environment.
error
Error facilities
escape
String escaping utilities
expansion
Word expansion utilities.
extensions
Definition of shell behavior traits and defaults.
functions
Structures for managing function registrations and calls.
history
Facilities for tracking and persisting the shell’s command history.
int_utils
Generic utilities.
interfaces
Exports traits for shell interfaces implemented by callers.
jobs
Job management
namedoptions
Defines shell options.
openfiles
Managing files open within a shell instance.
options
Defines runtime options for the shell.
parser
Re-export parser types used in core definitions.
pathcache
Path cache
pathsearch
Path searching utilities.
patterns
Shell patterns
processes
Process management
results
Encapsulation of execution results.
sourceinfo
Source info.
sys
Platform abstraction facilities
terminal
Terminal control utilities.
tests
Shell test conditional expressions
timing
Command timing
trace_categories
Trace utilities
traps
Facilities for configuring trap handlers.
variables
Implements variables for a shell environment.

Structs

CreateOptions
Options for creating a new shell.
ExecutionParameters
Parameters for execution.
Shell
Represents an instance of a shell.
ShellBuilder
Builder for Shell
SourcePosition
Represents a position in source text.
SourcePositionOffset
Represents an offset in source text.
SourceSpan
Represents a span within source text.

Enums

ProcessGroupPolicy
Policy for how to manage spawned external processes.
ProfileLoadBehavior
Behavior for loading profile files.
RcLoadBehavior
Behavior for loading rc files.

Traits

ShellBuilderState
Builder’s type state specifies if members are set or not (unset).
ShellState
A dyn-safe trait for constrained access to shell state.

Type Aliases

ShellFd
Type alias for shell file descriptors.