Module callstack

Module callstack 

Call stack representations.

Structs

CallStack
Encapsulates a script call stack.
FormatCallStack
Helper struct for formatting a call stack with custom options.
FormatOptions
Options for formatting a call stack.
Frame
Represents a single frame in a CallStack.
FunctionCall
Describes the target of a function call.
ScriptCall
Encapsulates info regarding a script call.

Enums

FrameType
Represents the type of a frame, indicating how it was invoked from a different source context.
ScriptCallType
The type of script call.