CallStack

Struct CallStack 

pub struct CallStack { /* private fields */ }
Encapsulates a script call stack.

Implementations

Source

impl CallStack

pub const fn format<'a>( &'a self, options: &'a FormatOptions, ) -> FormatCallStack<'a>

Creates a formatter for this call stack with the given options.

Arguments
  • options - The formatting options to use.
Source

impl CallStack

pub fn new() -> Self

Creates a new empty script call stack.

pub fn pop(&mut self) -> Option<Frame>

Removes the top from from the stack. If the stack is empty, does nothing and returns None; otherwise, returns the removed call frame.

pub fn current_frame(&self) -> Option<&Frame>

Returns a reference to the current (topmost) call frame in the stack. Returns None if the stack is empty.

pub fn current_pos_as_source_info(&self) -> SourceInfo

Returns the position in the current (topmost) call frame in the stack, expressed as a new SourceInfo. Note that this may not be identical to that frame’s SourceInfo since it may include an offset representing the current execution position within that source.

pub fn set_current_pos(&mut self, position: Option<Arc<SourcePosition>>)

Updates the currently executing position in the top stack frame.

pub fn push_script( &mut self, call_type: ScriptCallType, source_info: &SourceInfo, args: impl IntoIterator<Item = String>, )

Pushes a new script call frame onto the stack.

Arguments
  • call_type - The type of script call (sourced or executed).
  • source_info - The source of the script.
  • args - The positional arguments for the script call.
pub fn push_trap_handler( &mut self, signal: TrapSignal, handler: Option<&TrapHandler>, )

Pushes a new trap handler frame onto the stack.

Arguments
  • signal - The signal being handled.
  • handler - The trap handler being invoked, if any.
pub fn push_eval(&mut self)

Pushes a new eval frame onto the stack.

pub fn push_command_string(&mut self)

Pushes a new command string frame onto the stack.

pub fn push_interactive_session(&mut self)

Pushes a new interactive session frame onto the stack.

pub fn push_function( &mut self, name: impl Into<String>, function: &Registration, args: impl IntoIterator<Item = String>, )

Pushes a new function call frame onto the stack.

Arguments
  • name - The name of the function being called.
  • function - The function being called.
  • args - The positional arguments for the function call.
pub fn iter_function_calls(&self) -> impl Iterator<Item = &FunctionCall>

Iterates through the function calls on the stack.

pub fn iter_script_calls(&self) -> impl Iterator<Item = &ScriptCall>

Iterates through the script calls on the stack.

pub fn in_sourced_script(&self) -> bool

Returns whether or not the current script stack frame is a sourced script.

pub const fn function_call_depth(&self) -> usize

Returns the current depth of function calls in the call stack.

pub const fn script_source_depth(&self) -> usize

Returns the current depth of sourced script calls in the call stack.

pub fn is_trap_signal_active(&self, signal: TrapSignal) -> bool

Returns whether the given trap signal is currently being handled (i.e., there is an active frame on the stack for this signal).

pub fn clear_active_trap_signals(&mut self)

Clears the set of active trap signals. This should be called when creating subshells so they start with fresh trap execution state independent of the parent shell’s currently-executing traps.

pub const fn is_trap_delivery_suppressed(&self) -> bool

Returns whether the given trap signal is currently suppressed.

pub const fn acquire_trap_delivery_block(&mut self)

Acquires a block on trap delivery, preventing traps from being delivered until the block is released. Multiple blocks may be acquired, and trap delivery will remain suppressed until all blocks have been released.

pub const fn release_trap_delivery_block(&mut self)

Releases a block on trap delivery; note that trap delivery will remain suppressed until all blocks have been released.

pub fn in_function(&self) -> bool

Returns whether or not the shell is actively executing in a shell function.

pub fn depth(&self) -> usize

Returns the current depth of the call stack.

pub fn is_empty(&self) -> bool

Returns whether or not the call stack is empty.

pub fn iter(&self) -> impl Iterator<Item = &Frame>

Returns an iterator over the call frames, starting from the most recent.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Frame>

Returns a mutable iterator over the call frames, starting from the most recent.