pub struct FormatCallStack<'a> { /* private fields */ }Expand description
Helper struct for formatting a call stack with custom options.
This struct implements Display and can be used to write a formatted
call stack to any type that implements io::Write.
Implementations
Sourceimpl<'a> FormatCallStack<'a>
impl<'a> FormatCallStack<'a>
Sourcepub const fn new(stack: &'a CallStack, options: &'a FormatOptions) -> Self
pub const fn new(stack: &'a CallStack, options: &'a FormatOptions) -> Self
Creates a new formatter for the given call stack with the specified options.
Arguments
stack- The call stack to format.options- The formatting options to use.