Frame

Struct Frame 

pub struct Frame {
    pub frame_type: FrameType,
    pub source_info: SourceInfo,
    pub entry: Option<Arc<SourcePosition>>,
    pub current: Option<Arc<SourcePosition>>,
    pub args: Vec<String>,
    pub current_line_offset: usize,
}
Represents a single frame in a CallStack.

Fields

frame_type: FrameType

The type of frame.

source_info: SourceInfo

The source information for the frame. The locations associated with AST nodes executed in this frame should be interpreted as being relative to this source info.

entry: Option<Arc<SourcePosition>>

The location of the entry point into this frame, within the frame of reference of source_info. May be None if the entry point is not known.

current: Option<Arc<SourcePosition>>

Information about the currently executing location. For the topmost frame on the stack, this represents the current execution location. For older frames, this represents the site from which a control transfer was made to the next younger frame. May be None if the current location is not known. When present, it is relative to the frame of reference of source_info.

args: Vec<String>

Positional arguments (not including $0). May not be present for all frames.

current_line_offset: usize

Optionally, indicates an additional line offset within the current source context.

Implementations

Source

impl Frame

pub fn adjusted_source_info(&self) -> SourceInfo

Returns the adjusted source info for this frame, combining the frame’s source_info and current_line_offset, if present.

pub fn current_pos_as_source_info(&self) -> SourceInfo

Returns the current position as a new SourceInfo, combining the frame’s source_info and current position.

pub fn current_line(&self) -> Option<usize>

Returns the current line number.

pub fn current_frame_relative_line(&self) -> Option<usize>

Returns the current line number, relative to the frame’s entry.