Module completion

Module completion 

Implements programmable command completion support.

Structs

CompletionToken
Represents a token in the input line being completed.
Completions
Represents a set of generated command completions.
Config
Encapsulates the shell’s programmable command completion configuration.
Context
Encapsulates context used during completion generation.
FallbackOptions
Options for fallback completions.
GenerationOptions
Options for generating completions.
ProcessingOptions
Options governing how command completion candidates are processed after being generated.
Spec
Encapsulates a command completion specification; provides policy for how to generate completions for a given input.

Enums

Answer
Encapsulates a completion answer.
CompleteAction
Type of action to take to generate completion candidates.
CompleteOption
Options influencing how command completions are generated.
CompletionTrigger
Describes what triggered the completion process.