pub struct FallbackOptions {
pub mark_directories: bool,
pub mark_symlinked_directories: bool,
}Expand description
Options for fallback completions.
Fields
mark_directories: boolIf true, mark directory completions with a trailing slash.
mark_symlinked_directories: boolIf true, mark symlinked directory completions with a trailing slash.