Module error

Module error 

Error facilities

Structs

Error
Unified error type for this crate. Contains just a kind for now, but will be extended later with additional context.

Enums

ErrorKind
Monolithic error type for the shell

Traits

BuiltinError
Trait implementable by built-in commands to represent errors.
ConvertibleToExitCode
Helper trait for converting values to exit codes.

Functions

unimp
Convenience function for returning an error for unimplemented functionality.
unimp_with_issue
Convenience function for returning an error for tracked, unimplemented functionality.