pub struct Error { /* private fields */ }Expand description
Unified error type for this crate. Contains just a kind for now, but will be extended later with additional context.
Implementations
Sourceimpl Error
impl Error
Sourcepub const fn into_fatal(self) -> Self
pub const fn into_fatal(self) -> Self
Marks this error as fatal.
Sourcepub fn as_io_error(&self) -> Option<&Error>
pub fn as_io_error(&self) -> Option<&Error>
Try to extract a reference to the underlying std::io::Error, if any.
Sourcepub fn to_control_flow(
&self,
shell: &Shell<impl ShellExtensions>,
) -> ExecutionControlFlow
pub fn to_control_flow( &self, shell: &Shell<impl ShellExtensions>, ) -> ExecutionControlFlow
Converts this error into the appropriate control flow based on the shell’s current state. This centralizes the logic for determining how fatal errors should affect execution flow.
Arguments
shell- The shell instance, used to check interactive mode and script call stack.
Sourcepub fn into_result(self, shell: &Shell<impl ShellExtensions>) -> ExecutionResult
pub fn into_result(self, shell: &Shell<impl ShellExtensions>) -> ExecutionResult
Converts this error into an execution result for the shell.
Arguments
shell- The shell instance, used to determine control flow.