Module extensions

Module extensions 

Definition of shell behavior traits and defaults.

Structs

DefaultErrorFormatter
Default shell error behavior implementation.
DefaultPlaceholder
Default placeholder implementation.
ShellExtensionsImpl
Shell extensions implementation constructed from component types.

Traits

ErrorFormatter
Trait for defining shell error behaviors.
PlaceholderBehavior
Trait for placeholder behavior (stub for future extension).
ShellExtensions
Trait for static shell extensions. Collects all associated types needed to instantiate a shell into a single containing struct.

Type Aliases

DefaultShellExtensions
Default shell extensions implementation. This is a type alias for the most common shell configuration.