Module int_utils

Module int_utils 

Generic utilities.

Traits

ParseIntRadix
Trait for integer types that support parsing from strings with a radix.

Functions

parse
Parse the given string as an integer in the specified radix.