Module interfaces

Module interfaces 

Exports traits for shell interfaces implemented by callers.

Structs

KeyStroke
Represents a single key press.

Enums

InputFunction
Defines all input functions. Based on standard readline functions, augmented with some brush-specific extensions.
Key
Represents a single key.
KeyAction
Represents an action that can be taken in response to a key sequence.
KeySequence
Represents a sequence of keys.

Traits

KeyBindings
Encapsulates the shell’s interaction with key bindings for input.