pub struct JobManager {
pub jobs: Vec<Job>,
}Expand description
Manages the jobs that are currently managed by the shell.
Fields
jobs: Vec<Job>The jobs that are currently managed by the shell.
Implementations
Sourceimpl JobManager
impl JobManager
Sourcepub fn add_as_current(&mut self, job: Job) -> &Job
pub fn add_as_current(&mut self, job: Job) -> &Job
Adds a job to the job manager and marks it as the current job; returns an immutable reference to the job.
Arguments
job- The job to add.
Sourcepub fn current_job(&self) -> Option<&Job>
pub fn current_job(&self) -> Option<&Job>
Returns the current job, if there is one.
Sourcepub fn current_job_mut(&mut self) -> Option<&mut Job>
pub fn current_job_mut(&mut self) -> Option<&mut Job>
Returns a mutable reference to the current job, if there is one.
Sourcepub fn prev_job_mut(&mut self) -> Option<&mut Job>
pub fn prev_job_mut(&mut self) -> Option<&mut Job>
Returns a mutable reference to the previous job, if there is one.
Sourcepub fn resolve_job_spec(&mut self, job_spec: &str) -> Option<&mut Job>
pub fn resolve_job_spec(&mut self, job_spec: &str) -> Option<&mut Job>
Tries to resolve the given job specification to a job.
Arguments
job_spec- The job specification to resolve.