Module parser

Module parser 

Re-export parser types used in core definitions.

Modules

ast
Defines the Abstract Syntax Tree (ast) for shell programs. Includes types and utilities for manipulating the AST.

Structs

SourcePosition
Represents a position in source text.
SourcePositionOffset
Represents an offset in source text.
SourceSpan
Represents a span within source text.
TestCommandParseError
Represents an error that occurred while parsing a (non-extended) test command.

Enums

BindingParseError
Represents an error that occurred while parsing a key-binding specification.
ParseError
Represents an error that occurred while parsing tokens.
ParserImpl
Parser implementation to use
WordParseError
Represents an error that occurred while parsing a word.