pub enum Command {
Simple(SimpleCommand),
Compound(CompoundCommand, Option<RedirectList>),
Function(FunctionDefinition),
ExtendedTest(ExtendedTestExprCommand, Option<RedirectList>),
}Expand description
Represents a shell command.
Variants
Simple(SimpleCommand)
A simple command, directly invoking an external command, a built-in command, a shell function, or similar.
Compound(CompoundCommand, Option<RedirectList>)
A compound command, composed of multiple commands.
Function(FunctionDefinition)
A command whose side effect is to define a shell function.
ExtendedTest(ExtendedTestExprCommand, Option<RedirectList>)
A command that evaluates an extended test expression.