search_for_executable

Function search_for_executable 

pub fn search_for_executable<P, PI, N>(
    paths: P,
    filename: N,
) -> ExecutablePathSearch<PI, N> 
where P: Iterator<Item = PI>, PI: AsRef<str>, N: AsRef<str>,
Search for the given executable name in the provided paths.

Arguments

  • paths - An iterator over the paths to search.
  • filename - The name of the executable file to search for.