pub struct SourceInfo {
pub source: String,
pub start: Option<Arc<SourcePosition>>,
}Expand description
Source context.
Fields
source: StringThe name of the source.
start: Option<Arc<SourcePosition>>Optionally indicates a starting location after the beginning of the source.
If None, the start is the beginning of the source.