pub struct ExecutionParameters {
pub process_group_policy: ProcessGroupPolicy,
pub suppress_errexit: bool,
/* private fields */
}Expand description
Parameters for execution.
Fields
process_group_policy: ProcessGroupPolicyPolicy for how to manage spawned external processes.
suppress_errexit: boolWhether errexit (exit on error) behavior should be
suppressed in this execution context. Defaults to false.
Implementations
Sourceimpl ExecutionParameters
impl ExecutionParameters
Sourcepub fn stdin(&self, shell: &Shell<impl ShellExtensions>) -> impl Read + 'static
pub fn stdin(&self, shell: &Shell<impl ShellExtensions>) -> impl Read + 'static
Sourcepub fn try_stdin(&self, shell: &Shell<impl ShellExtensions>) -> Option<OpenFile>
pub fn try_stdin(&self, shell: &Shell<impl ShellExtensions>) -> Option<OpenFile>
Tries to retrieve the standard input file. Returns None if not set.
Arguments
shell- The shell context.
Sourcepub fn stdout(
&self,
shell: &Shell<impl ShellExtensions>,
) -> impl Write + 'static
pub fn stdout( &self, shell: &Shell<impl ShellExtensions>, ) -> impl Write + 'static
Returns the standard output file; usable with write! et al. In the event that
no such file is available, returns a valid implementation of std::io::Write
that fails all I/O requests.
Arguments
shell- The shell context.
Sourcepub fn try_stdout(
&self,
shell: &Shell<impl ShellExtensions>,
) -> Option<OpenFile>
pub fn try_stdout( &self, shell: &Shell<impl ShellExtensions>, ) -> Option<OpenFile>
Tries to retrieve the standard output file. Returns None if not set.
Arguments
shell- The shell context.
Sourcepub fn stderr(
&self,
shell: &Shell<impl ShellExtensions>,
) -> impl Write + 'static
pub fn stderr( &self, shell: &Shell<impl ShellExtensions>, ) -> impl Write + 'static
Returns the standard error file; usable with write! et al. In the event that
no such file is available, returns a valid implementation of std::io::Write
that fails all I/O requests.
Arguments
shell- The shell context.
Sourcepub fn try_stderr(
&self,
shell: &Shell<impl ShellExtensions>,
) -> Option<OpenFile>
pub fn try_stderr( &self, shell: &Shell<impl ShellExtensions>, ) -> Option<OpenFile>
Tries to retrieve the standard error file. Returns None if not set.
Arguments
shell- The shell context.
Sourcepub fn try_fd(
&self,
shell: &Shell<impl ShellExtensions>,
fd: ShellFd,
) -> Option<OpenFile>
pub fn try_fd( &self, shell: &Shell<impl ShellExtensions>, fd: ShellFd, ) -> Option<OpenFile>
Returns the file descriptor with the given number. Returns None
if the file descriptor is not open.
Arguments
shell- The shell context.fd- The file descriptor number to retrieve.