ShellBuilder

Struct ShellBuilder 

pub struct ShellBuilder<SE: ShellExtensions = DefaultShellExtensions, S: State = Empty> { /* private fields */ }
Builder for Shell

Implementations

Source

impl<SE: ShellExtensions, S: IsComplete> ShellBuilder<SE, S>

pub async fn build(self) -> Result<Shell<SE>, Error>

Returns a new shell instance created with the options provided. Runs any configuration loading as well.

Source

impl<SE: ShellExtensions, S: State> ShellBuilder<SE, S>

pub fn disable_option(self, option: impl Into<String>) -> Self

Add a disabled option

pub fn enable_option(self, option: impl Into<String>) -> Self

Add an enabled option

pub fn disable_options( self, options: impl IntoIterator<Item: Into<String>>, ) -> Self

Add many disabled options

pub fn enable_options( self, options: impl IntoIterator<Item: Into<String>>, ) -> Self

Add many enabled options

pub fn disable_shopt_option(self, option: impl Into<String>) -> Self

Add a disabled shopt option

pub fn enable_shopt_option(self, option: impl Into<String>) -> Self

Add an enabled shopt option

pub fn disable_shopt_options( self, options: impl IntoIterator<Item: Into<String>>, ) -> Self

Add many disabled shopt options

pub fn enable_shopt_options( self, options: impl IntoIterator<Item: Into<String>>, ) -> Self

Add many enabled shopt options

pub fn builtin(self, name: impl Into<String>, reg: Registration<SE>) -> Self

Add a single builtin registration

pub fn builtins( self, builtins: impl IntoIterator<Item = (String, Registration<SE>)>, ) -> Self

Add many builtin registrations

pub fn var(self, name: impl Into<String>, variable: ShellVariable) -> Self

Adds a single variable to be initialized in the shell.

Source

impl<SE: ShellExtensions, S: State> ShellBuilder<SE, S>

pub fn error_formatter( self, value: SE::ErrorFormatter, ) -> ShellBuilder<SE, SetErrorFormatter<S>>
where S::ErrorFormatter: IsUnset,

Optional (Some / Option setters). Default: <SE::ErrorFormatter as Default>::default().

Error behavior implementation.

pub fn maybe_error_formatter( self, value: Option<SE::ErrorFormatter>, ) -> ShellBuilder<SE, SetErrorFormatter<S>>
where S::ErrorFormatter: IsUnset,

Optional (Some / Option setters). Default: <SE::ErrorFormatter as Default>::default().

Error behavior implementation.

pub fn disallow_overwriting_regular_files_via_output_redirection( self, value: bool, ) -> ShellBuilder<SE, SetDisallowOverwritingRegularFilesViaOutputRedirection<S>>

Optional (Some / Option setters). Default: false.

Disallow overwriting regular files via output redirection.

pub fn maybe_disallow_overwriting_regular_files_via_output_redirection( self, value: Option<bool>, ) -> ShellBuilder<SE, SetDisallowOverwritingRegularFilesViaOutputRedirection<S>>

Optional (Some / Option setters). Default: false.

Disallow overwriting regular files via output redirection.

pub fn do_not_execute_commands( self, value: bool, ) -> ShellBuilder<SE, SetDoNotExecuteCommands<S>>
where S::DoNotExecuteCommands: IsUnset,

Optional (Some / Option setters). Default: false.

Do not execute commands.

pub fn maybe_do_not_execute_commands( self, value: Option<bool>, ) -> ShellBuilder<SE, SetDoNotExecuteCommands<S>>
where S::DoNotExecuteCommands: IsUnset,

Optional (Some / Option setters). Default: false.

Do not execute commands.

pub fn exit_after_one_command( self, value: bool, ) -> ShellBuilder<SE, SetExitAfterOneCommand<S>>
where S::ExitAfterOneCommand: IsUnset,

Optional (Some / Option setters). Default: false.

Exit after one command.

pub fn maybe_exit_after_one_command( self, value: Option<bool>, ) -> ShellBuilder<SE, SetExitAfterOneCommand<S>>
where S::ExitAfterOneCommand: IsUnset,

Optional (Some / Option setters). Default: false.

Exit after one command.

pub fn interactive(self, value: bool) -> ShellBuilder<SE, SetInteractive<S>>
where S::Interactive: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is interactive.

pub fn maybe_interactive( self, value: Option<bool>, ) -> ShellBuilder<SE, SetInteractive<S>>
where S::Interactive: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is interactive.

pub fn login(self, value: bool) -> ShellBuilder<SE, SetLogin<S>>
where S::Login: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is a login shell.

pub fn maybe_login(self, value: Option<bool>) -> ShellBuilder<SE, SetLogin<S>>
where S::Login: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is a login shell.

pub fn no_editing(self, value: bool) -> ShellBuilder<SE, SetNoEditing<S>>
where S::NoEditing: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to skip using a readline-like interface for input.

pub fn maybe_no_editing( self, value: Option<bool>, ) -> ShellBuilder<SE, SetNoEditing<S>>
where S::NoEditing: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to skip using a readline-like interface for input.

pub fn profile( self, value: ProfileLoadBehavior, ) -> ShellBuilder<SE, SetProfile<S>>
where S::Profile: IsUnset,

Optional (Some / Option setters). Default: <ProfileLoadBehavior as Default>::default().

System profile loading behavior.

pub fn maybe_profile( self, value: Option<ProfileLoadBehavior>, ) -> ShellBuilder<SE, SetProfile<S>>
where S::Profile: IsUnset,

Optional (Some / Option setters). Default: <ProfileLoadBehavior as Default>::default().

System profile loading behavior.

pub fn rc(self, value: RcLoadBehavior) -> ShellBuilder<SE, SetRc<S>>
where S::Rc: IsUnset,

Optional (Some / Option setters). Default: <RcLoadBehavior as Default>::default().

Rc file loading behavior.

pub fn maybe_rc( self, value: Option<RcLoadBehavior>, ) -> ShellBuilder<SE, SetRc<S>>
where S::Rc: IsUnset,

Optional (Some / Option setters). Default: <RcLoadBehavior as Default>::default().

Rc file loading behavior.

pub fn do_not_inherit_env( self, value: bool, ) -> ShellBuilder<SE, SetDoNotInheritEnv<S>>
where S::DoNotInheritEnv: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to skip inheriting environment variables from the calling process.

pub fn maybe_do_not_inherit_env( self, value: Option<bool>, ) -> ShellBuilder<SE, SetDoNotInheritEnv<S>>
where S::DoNotInheritEnv: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to skip inheriting environment variables from the calling process.

pub fn skip_well_known_vars( self, value: bool, ) -> ShellBuilder<SE, SetSkipWellKnownVars<S>>
where S::SkipWellKnownVars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to skip initializing well-known variables.

pub fn maybe_skip_well_known_vars( self, value: Option<bool>, ) -> ShellBuilder<SE, SetSkipWellKnownVars<S>>
where S::SkipWellKnownVars: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to skip initializing well-known variables.

pub fn fds( self, value: HashMap<ShellFd, OpenFile>, ) -> ShellBuilder<SE, SetFds<S>>
where S::Fds: IsUnset,

Optional (Some / Option setters). Default: <HashMap<ShellFd, openfiles::OpenFile> as Default>::default().

Provides a set of initial open files to be tracked by the shell.

pub fn maybe_fds( self, value: Option<HashMap<ShellFd, OpenFile>>, ) -> ShellBuilder<SE, SetFds<S>>
where S::Fds: IsUnset,

Optional (Some / Option setters). Default: <HashMap<ShellFd, openfiles::OpenFile> as Default>::default().

Provides a set of initial open files to be tracked by the shell.

pub fn external_cmd_leads_session( self, value: bool, ) -> ShellBuilder<SE, SetExternalCmdLeadsSession<S>>
where S::ExternalCmdLeadsSession: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to launch external commands as session leaders.

pub fn maybe_external_cmd_leads_session( self, value: Option<bool>, ) -> ShellBuilder<SE, SetExternalCmdLeadsSession<S>>
where S::ExternalCmdLeadsSession: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to launch external commands as session leaders.

pub fn working_dir(self, value: PathBuf) -> ShellBuilder<SE, SetWorkingDir<S>>
where S::WorkingDir: IsUnset,

Optional (Some / Option setters). Initial working dir for the shell. If left unspecified, will be populated from the host environment.

pub fn maybe_working_dir( self, value: Option<PathBuf>, ) -> ShellBuilder<SE, SetWorkingDir<S>>
where S::WorkingDir: IsUnset,

Optional (Some / Option setters). Initial working dir for the shell. If left unspecified, will be populated from the host environment.

pub fn posix(self, value: bool) -> ShellBuilder<SE, SetPosix<S>>
where S::Posix: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is in POSIX compliance mode.

pub fn maybe_posix(self, value: Option<bool>) -> ShellBuilder<SE, SetPosix<S>>
where S::Posix: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is in POSIX compliance mode.

pub fn print_commands_and_arguments( self, value: bool, ) -> ShellBuilder<SE, SetPrintCommandsAndArguments<S>>
where S::PrintCommandsAndArguments: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to print commands and arguments as they are read.

pub fn maybe_print_commands_and_arguments( self, value: Option<bool>, ) -> ShellBuilder<SE, SetPrintCommandsAndArguments<S>>
where S::PrintCommandsAndArguments: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to print commands and arguments as they are read.

pub fn read_commands_from_stdin( self, value: bool, ) -> ShellBuilder<SE, SetReadCommandsFromStdin<S>>
where S::ReadCommandsFromStdin: IsUnset,

Optional (Some / Option setters). Default: false.

Whether commands are being read from stdin.

pub fn maybe_read_commands_from_stdin( self, value: Option<bool>, ) -> ShellBuilder<SE, SetReadCommandsFromStdin<S>>
where S::ReadCommandsFromStdin: IsUnset,

Optional (Some / Option setters). Default: false.

Whether commands are being read from stdin.

pub fn shell_name(self, value: String) -> ShellBuilder<SE, SetShellName<S>>
where S::ShellName: IsUnset,

Optional (Some / Option setters). The name of the shell.

pub fn maybe_shell_name( self, value: Option<String>, ) -> ShellBuilder<SE, SetShellName<S>>
where S::ShellName: IsUnset,

Optional (Some / Option setters). The name of the shell.

pub fn shell_args(self, value: Vec<String>) -> ShellBuilder<SE, SetShellArgs<S>>
where S::ShellArgs: IsUnset,

Optional (Some / Option setters). Base positional arguments for the shell (not including the shell name).

pub fn maybe_shell_args( self, value: Option<Vec<String>>, ) -> ShellBuilder<SE, SetShellArgs<S>>
where S::ShellArgs: IsUnset,

Optional (Some / Option setters). Base positional arguments for the shell (not including the shell name).

pub fn shell_product_display_str( self, value: String, ) -> ShellBuilder<SE, SetShellProductDisplayStr<S>>
where S::ShellProductDisplayStr: IsUnset,

Optional (Some / Option setters). Optionally provides a display string describing the version and variant of the shell.

pub fn maybe_shell_product_display_str( self, value: Option<String>, ) -> ShellBuilder<SE, SetShellProductDisplayStr<S>>
where S::ShellProductDisplayStr: IsUnset,

Optional (Some / Option setters). Optionally provides a display string describing the version and variant of the shell.

pub fn sh_mode(self, value: bool) -> ShellBuilder<SE, SetShMode<S>>
where S::ShMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to run in maximal POSIX sh compatibility mode.

pub fn maybe_sh_mode( self, value: Option<bool>, ) -> ShellBuilder<SE, SetShMode<S>>
where S::ShMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to run in maximal POSIX sh compatibility mode.

pub fn treat_unset_variables_as_error( self, value: bool, ) -> ShellBuilder<SE, SetTreatUnsetVariablesAsError<S>>
where S::TreatUnsetVariablesAsError: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to treat expansion of unset variables as an error.

pub fn maybe_treat_unset_variables_as_error( self, value: Option<bool>, ) -> ShellBuilder<SE, SetTreatUnsetVariablesAsError<S>>
where S::TreatUnsetVariablesAsError: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to treat expansion of unset variables as an error.

pub fn exit_on_nonzero_command_exit( self, value: bool, ) -> ShellBuilder<SE, SetExitOnNonzeroCommandExit<S>>
where S::ExitOnNonzeroCommandExit: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to enable error-on-exit behavior.

pub fn maybe_exit_on_nonzero_command_exit( self, value: Option<bool>, ) -> ShellBuilder<SE, SetExitOnNonzeroCommandExit<S>>
where S::ExitOnNonzeroCommandExit: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to enable error-on-exit behavior.

pub fn disable_pathname_expansion( self, value: bool, ) -> ShellBuilder<SE, SetDisablePathnameExpansion<S>>
where S::DisablePathnameExpansion: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to disable pathname expansion.

pub fn maybe_disable_pathname_expansion( self, value: Option<bool>, ) -> ShellBuilder<SE, SetDisablePathnameExpansion<S>>
where S::DisablePathnameExpansion: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to disable pathname expansion.

pub fn verbose(self, value: bool) -> ShellBuilder<SE, SetVerbose<S>>
where S::Verbose: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to print verbose output.

pub fn maybe_verbose( self, value: Option<bool>, ) -> ShellBuilder<SE, SetVerbose<S>>
where S::Verbose: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to print verbose output.

pub fn parser(self, value: ParserImpl) -> ShellBuilder<SE, SetParser<S>>
where S::Parser: IsUnset,

Optional (Some / Option setters). Default: <crate::parser::ParserImpl as Default>::default().

Parser implementation to use.

pub fn maybe_parser( self, value: Option<ParserImpl>, ) -> ShellBuilder<SE, SetParser<S>>
where S::Parser: IsUnset,

Optional (Some / Option setters). Default: <crate::parser::ParserImpl as Default>::default().

Parser implementation to use.

pub fn command_string_mode( self, value: bool, ) -> ShellBuilder<SE, SetCommandStringMode<S>>
where S::CommandStringMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is in command string mode (-c).

pub fn maybe_command_string_mode( self, value: Option<bool>, ) -> ShellBuilder<SE, SetCommandStringMode<S>>
where S::CommandStringMode: IsUnset,

Optional (Some / Option setters). Default: false.

Whether the shell is in command string mode (-c).

pub fn max_function_call_depth( self, value: usize, ) -> ShellBuilder<SE, SetMaxFunctionCallDepth<S>>
where S::MaxFunctionCallDepth: IsUnset,

Optional (Some / Option setters). Maximum function call depth.

pub fn maybe_max_function_call_depth( self, value: Option<usize>, ) -> ShellBuilder<SE, SetMaxFunctionCallDepth<S>>
where S::MaxFunctionCallDepth: IsUnset,

Optional (Some / Option setters). Maximum function call depth.

pub fn key_bindings( self, value: Arc<Mutex<dyn KeyBindings>>, ) -> ShellBuilder<SE, SetKeyBindings<S>>
where S::KeyBindings: IsUnset,

Optional (Some / Option setters). Key bindings helper for the shell to use.

pub fn maybe_key_bindings( self, value: Option<Arc<Mutex<dyn KeyBindings>>>, ) -> ShellBuilder<SE, SetKeyBindings<S>>
where S::KeyBindings: IsUnset,

Optional (Some / Option setters). Key bindings helper for the shell to use.

pub fn shell_version( self, value: String, ) -> ShellBuilder<SE, SetShellVersion<S>>
where S::ShellVersion: IsUnset,

Optional (Some / Option setters). Brush implementation version.

pub fn maybe_shell_version( self, value: Option<String>, ) -> ShellBuilder<SE, SetShellVersion<S>>
where S::ShellVersion: IsUnset,

Optional (Some / Option setters). Brush implementation version.