CommandFgControlExt

Trait CommandFgControlExt 

pub trait CommandFgControlExt {
    // Required methods
    fn take_foreground(&mut self);
    fn lead_session(&mut self);
}
Extension trait for arranging for commands to take the foreground.

Required Methods

fn take_foreground(&mut self)

Arranges for the command to take the foreground when it is executed.

fn lead_session(&mut self)

Arranges for the command to become a session leader when it is executed.

Implementations on Foreign Types

Source

impl CommandFgControlExt for Command

Implementors