ShellBuilderState

Trait ShellBuilderState 

pub trait ShellBuilderState: Sized {
Show 30 associated items type ErrorFormatter; type DisallowOverwritingRegularFilesViaOutputRedirection; type DoNotExecuteCommands; type ExitAfterOneCommand; type Interactive; type Login; type NoEditing; type Profile; type Rc; type DoNotInheritEnv; type SkipWellKnownVars; type Fds; type ExternalCmdLeadsSession; type WorkingDir; type Posix; type PrintCommandsAndArguments; type ReadCommandsFromStdin; type ShellName; type ShellArgs; type ShellProductDisplayStr; type ShMode; type TreatUnsetVariablesAsError; type ExitOnNonzeroCommandExit; type DisablePathnameExpansion; type Verbose; type Parser; type CommandStringMode; type MaxFunctionCallDepth; type KeyBindings; type ShellVersion;
}
Builder’s type state specifies if members are set or not (unset).

You can use the associated types of this trait to control the state of individual members with the [IsSet] and [IsUnset] traits. You can change the state of the members with the Set* structs available in this module.

Required Associated Types

type ErrorFormatter

Type state of the member error_formatter.

It can implement either [IsSet] or [IsUnset]

type DisallowOverwritingRegularFilesViaOutputRedirection

Type state of the member disallow_overwriting_regular_files_via_output_redirection.

It can implement either [IsSet] or [IsUnset]

type DoNotExecuteCommands

Type state of the member do_not_execute_commands.

It can implement either [IsSet] or [IsUnset]

type ExitAfterOneCommand

Type state of the member exit_after_one_command.

It can implement either [IsSet] or [IsUnset]

type Interactive

Type state of the member interactive.

It can implement either [IsSet] or [IsUnset]

type Login

Type state of the member login.

It can implement either [IsSet] or [IsUnset]

type NoEditing

Type state of the member no_editing.

It can implement either [IsSet] or [IsUnset]

type Profile

Type state of the member profile.

It can implement either [IsSet] or [IsUnset]

type Rc

Type state of the member rc.

It can implement either [IsSet] or [IsUnset]

type DoNotInheritEnv

Type state of the member do_not_inherit_env.

It can implement either [IsSet] or [IsUnset]

type SkipWellKnownVars

Type state of the member skip_well_known_vars.

It can implement either [IsSet] or [IsUnset]

type Fds

Type state of the member fds.

It can implement either [IsSet] or [IsUnset]

type ExternalCmdLeadsSession

Type state of the member external_cmd_leads_session.

It can implement either [IsSet] or [IsUnset]

type WorkingDir

Type state of the member working_dir.

It can implement either [IsSet] or [IsUnset]

type Posix

Type state of the member posix.

It can implement either [IsSet] or [IsUnset]

type PrintCommandsAndArguments

Type state of the member print_commands_and_arguments.

It can implement either [IsSet] or [IsUnset]

type ReadCommandsFromStdin

Type state of the member read_commands_from_stdin.

It can implement either [IsSet] or [IsUnset]

type ShellName

Type state of the member shell_name.

It can implement either [IsSet] or [IsUnset]

type ShellArgs

Type state of the member shell_args.

It can implement either [IsSet] or [IsUnset]

type ShellProductDisplayStr

Type state of the member shell_product_display_str.

It can implement either [IsSet] or [IsUnset]

type ShMode

Type state of the member sh_mode.

It can implement either [IsSet] or [IsUnset]

type TreatUnsetVariablesAsError

Type state of the member treat_unset_variables_as_error.

It can implement either [IsSet] or [IsUnset]

type ExitOnNonzeroCommandExit

Type state of the member exit_on_nonzero_command_exit.

It can implement either [IsSet] or [IsUnset]

type DisablePathnameExpansion

Type state of the member disable_pathname_expansion.

It can implement either [IsSet] or [IsUnset]

type Verbose

Type state of the member verbose.

It can implement either [IsSet] or [IsUnset]

type Parser

Type state of the member parser.

It can implement either [IsSet] or [IsUnset]

type CommandStringMode

Type state of the member command_string_mode.

It can implement either [IsSet] or [IsUnset]

type MaxFunctionCallDepth

Type state of the member max_function_call_depth.

It can implement either [IsSet] or [IsUnset]

type KeyBindings

Type state of the member key_bindings.

It can implement either [IsSet] or [IsUnset]

type ShellVersion

Type state of the member shell_version.

It can implement either [IsSet] or [IsUnset]

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors