pub enum ShellValue {
Unset(ShellValueUnsetType),
String(String),
AssociativeArray(BTreeMap<String, String>),
IndexedArray(BTreeMap<u64, String>),
Dynamic {
getter: fn(&dyn ShellState) -> ShellValue,
setter: fn(&dyn ShellState),
},
}Expand description
A shell value.
Variants
Unset(ShellValueUnsetType)
A value that has been typed but not yet set.
String(String)
A string.
AssociativeArray(BTreeMap<String, String>)
An associative array.
IndexedArray(BTreeMap<u64, String>)
An indexed array.
Dynamic
A value that is dynamically computed.
Fields
getter: fn(&dyn ShellState) -> ShellValueFunction that can query the value. TODO(serde): figure out how to serialize/deserialize dynamic values.
setter: fn(&dyn ShellState)Function that receives value update requests. TODO(serde): figure out how to serialize/deserialize dynamic values.
Implementations
Sourceimpl ShellValue
impl ShellValue
Sourcepub fn indexed_array_from_strings<S>(values: S) -> Selfwhere
S: IntoIterator<Item = String>,
pub fn indexed_array_from_strings<S>(values: S) -> Selfwhere
S: IntoIterator<Item = String>,
Returns a new indexed array value constructed from the given slice of owned strings.
Arguments
values- The slice of strings to construct the indexed array from.
Sourcepub fn indexed_array_from_strs(values: &[&str]) -> Self
pub fn indexed_array_from_strs(values: &[&str]) -> Self
Returns a new indexed array value constructed from the given slice of unowned strings.
Arguments
values- The slice of strings to construct the indexed array from.
Sourcepub fn indexed_array_from_literals(literals: ArrayLiteral) -> Self
pub fn indexed_array_from_literals(literals: ArrayLiteral) -> Self
Returns a new indexed array value constructed from the given literals.
Arguments
literals- The literals to construct the indexed array from.
Sourcepub fn associative_array_from_literals(
literals: ArrayLiteral,
) -> Result<Self, Error>
pub fn associative_array_from_literals( literals: ArrayLiteral, ) -> Result<Self, Error>
Returns a new associative array value constructed from the given literals.
Arguments
literals- The literals to construct the associative array from.
Sourcepub fn format(
&self,
style: FormatStyle,
shell: &Shell<impl ShellExtensions>,
) -> Result<Cow<'_, str>, Error>
pub fn format( &self, style: FormatStyle, shell: &Shell<impl ShellExtensions>, ) -> Result<Cow<'_, str>, Error>
Formats the value using the given style.
Arguments
style- The style to use for formatting the value.
Sourcepub fn get_at(
&self,
index: &str,
shell: &Shell<impl ShellExtensions>,
) -> Result<Option<Cow<'_, str>>, Error>
pub fn get_at( &self, index: &str, shell: &Shell<impl ShellExtensions>, ) -> Result<Option<Cow<'_, str>>, Error>
Tries to retrieve the value stored at the given index in this variable.
Arguments
index- The index at which to retrieve the value.
Sourcepub fn element_keys(&self, shell: &Shell<impl ShellExtensions>) -> Vec<String>
pub fn element_keys(&self, shell: &Shell<impl ShellExtensions>) -> Vec<String>
Returns the keys of the elements in this variable.
Sourcepub fn element_values(&self, shell: &Shell<impl ShellExtensions>) -> Vec<String>
pub fn element_values(&self, shell: &Shell<impl ShellExtensions>) -> Vec<String>
Returns the values of the elements in this variable.
Sourcepub fn to_cow_str(&self, shell: &Shell<impl ShellExtensions>) -> Cow<'_, str>
pub fn to_cow_str(&self, shell: &Shell<impl ShellExtensions>) -> Cow<'_, str>
Converts this value to a string.
Sourcepub fn try_get_cow_str(
&self,
shell: &Shell<impl ShellExtensions>,
) -> Option<Cow<'_, str>>
pub fn try_get_cow_str( &self, shell: &Shell<impl ShellExtensions>, ) -> Option<Cow<'_, str>>
Tries to convert this value to a string; returns None if the value is unset
or otherwise doesn’t exist.
Sourcepub fn to_assignable_str(
&self,
index: Option<&str>,
shell: &Shell<impl ShellExtensions>,
) -> Result<String, Error>
pub fn to_assignable_str( &self, index: Option<&str>, shell: &Shell<impl ShellExtensions>, ) -> Result<String, Error>
Formats this value as a program string usable in an assignment.
Arguments
index- The index at which to retrieve the value, if indexing is to be performed.