Call stack representations.
Structs
- Call
Stack - Encapsulates a script call stack.
- Format
Call Stack - Helper struct for formatting a call stack with custom options.
- Format
Options - Options for formatting a call stack.
- Frame
- Represents a single frame in a
CallStack. - Function
Call - Describes the target of a function call.
- Script
Call - Encapsulates info regarding a script call.
Enums
- Frame
Type - Represents the type of a frame, indicating how it was invoked from a different source context.
- Script
Call Type - The type of script call.