Definition of shell behavior traits and defaults.
Structs
- Default
Error Formatter - Default shell error behavior implementation.
- Default
Placeholder - Default placeholder implementation.
- Shell
Extensions Impl - Shell extensions implementation constructed from component types.
Traits
- Error
Formatter - Trait for defining shell error behaviors.
- Placeholder
Behavior - Trait for placeholder behavior (stub for future extension).
- Shell
Extensions - Trait for static shell extensions. Collects all associated types needed to instantiate a shell into a single containing struct.
Type Aliases
- Default
Shell Extensions - Default shell extensions implementation. This is a type alias for the most common shell configuration.