pub trait ParseIntRadix: Sized {
// Required methods
fn from_str_radix(s: &str, radix: u32) -> Result<Self, ParseIntError>;
fn type_name() -> &'static str;
}Expand description
Trait for integer types that support parsing from strings with a radix.
Required Methods
Sourcefn from_str_radix(s: &str, radix: u32) -> Result<Self, ParseIntError>
fn from_str_radix(s: &str, radix: u32) -> Result<Self, ParseIntError>
Parse a string as this integer type using the specified radix.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.