Re-export parser types used in core definitions.
Modules
- ast
- Defines the Abstract Syntax Tree (ast) for shell programs. Includes types and utilities for manipulating the AST.
Structs
- Source
Position - Represents a position in source text.
- Source
Position Offset - Represents an offset in source text.
- Source
Span - Represents a span within source text.
- Test
Command Parse Error - Represents an error that occurred while parsing a (non-extended) test command.
Enums
- Binding
Parse Error - Represents an error that occurred while parsing a key-binding specification.
- Parse
Error - Represents an error that occurred while parsing tokens.
- Parser
Impl - Parser implementation to use
- Word
Parse Error - Represents an error that occurred while parsing a word.