pub fn search_for_executable<P, PI, N>(
paths: P,
filename: N,
) -> ExecutablePathSearch<PI, N> ⓘExpand description
Search for the given executable name in the provided paths.
Arguments
paths- An iterator over the paths to search.filename- The name of the executable file to search for.