pub struct Shell<SE: ShellExtensions = DefaultShellExtensions> { /* private fields */ }Expand description
Represents an instance of a shell.
Type Parameters
SE- The shell extensions implementation to use. These extensions are statically injected into the shell at compile time to provide custom behavior. When unspecified, defaults toDefaultShellExtensions, which provide standard behavior.
Implementations
Sourceimpl Shell
impl Shell
Sourcepub fn builder() -> ShellBuilder<DefaultShellExtensions, Empty>
pub fn builder() -> ShellBuilder<DefaultShellExtensions, Empty>
Create an instance of Shell using the builder syntax
Sourcepub fn builder_with_extensions<SE: ShellExtensions>() -> ShellBuilder<SE, Empty>
pub fn builder_with_extensions<SE: ShellExtensions>() -> ShellBuilder<SE, Empty>
Create an instance of Shell using the builder syntax, with custom extensions.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn register_builtin<S: Into<String>>(
&mut self,
name: S,
registration: Registration<SE>,
)
pub fn register_builtin<S: Into<String>>( &mut self, name: S, registration: Registration<SE>, )
Register a builtin to the shell’s environment, replacing any existing registration with the same name.
Arguments
name- The in-shell name of the builtin.registration- The registration handle for the builtin.
Sourcepub fn register_builtin_if_unset<S: Into<String>>(
&mut self,
name: S,
registration: Registration<SE>,
)
pub fn register_builtin_if_unset<S: Into<String>>( &mut self, name: S, registration: Registration<SE>, )
Register a builtin only if no builtin with that name is already registered.
Arguments
name- The in-shell name of the builtin.registration- The registration handle for the builtin.
Sourcepub fn builtin_mut(&mut self, name: &str) -> Option<&mut Registration<SE>>
pub fn builtin_mut(&mut self, name: &str) -> Option<&mut Registration<SE>>
Tries to retrieve a mutable reference to an existing builtin registration.
Returns None if no such registration exists.
Arguments
name- The name of the builtin to lookup.
Sourcepub const fn builtins(&self) -> &HashMap<String, Registration<SE>>
pub const fn builtins(&self) -> &HashMap<String, Registration<SE>>
Returns the registered builtins for the shell.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn in_sourced_script(&self) -> bool
pub fn in_sourced_script(&self) -> bool
Returns whether or not the shell is actively executing in a sourced script.
Sourcepub fn in_function(&self) -> bool
pub fn in_function(&self) -> bool
Returns whether or not the shell is actively executing in a shell function.
Sourcepub fn start_interactive_session(&mut self) -> Result<(), Error>
pub fn start_interactive_session(&mut self) -> Result<(), Error>
Updates the shell’s internal tracking state to reflect that a new interactive session is being started.
Sourcepub fn end_interactive_session(&mut self) -> Result<(), Error>
pub fn end_interactive_session(&mut self) -> Result<(), Error>
Updates the shell’s internal tracking state to reflect that the current interactive session is ending.
Sourcepub fn start_command_string_mode(&mut self)
pub fn start_command_string_mode(&mut self)
Updates the shell’s internal tracking state to reflect that command string mode is being started.
Sourcepub fn end_command_string_mode(&mut self) -> Result<(), Error>
pub fn end_command_string_mode(&mut self) -> Result<(), Error>
Updates the shell’s internal tracking state to reflect that command string mode is ending.
Sourcepub fn current_shell_args(&self) -> &[String]
pub fn current_shell_args(&self) -> &[String]
Returns the current positional arguments for the shell ($1 and beyond). Influenced by the current call stack.
Sourcepub fn current_shell_args_mut(&mut self) -> &mut Vec<String>
pub fn current_shell_args_mut(&mut self) -> &mut Vec<String>
Returns a mutable reference to current positional parameters for the shell ($1 and beyond).
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn env_str(&self, name: &str) -> Option<Cow<'_, str>>
pub fn env_str(&self, name: &str) -> Option<Cow<'_, str>>
Tries to retrieve a variable from the shell’s environment, converting it into its string form.
Arguments
name- The name of the variable to retrieve.
Sourcepub fn env_var(&self, name: &str) -> Option<&ShellVariable>
pub fn env_var(&self, name: &str) -> Option<&ShellVariable>
Tries to retrieve a variable from the shell’s environment.
Arguments
name- The name of the variable to retrieve.
Sourcepub fn set_env_global(
&mut self,
name: &str,
var: ShellVariable,
) -> Result<(), Error>
pub fn set_env_global( &mut self, name: &str, var: ShellVariable, ) -> Result<(), Error>
Tries to set a global variable in the shell’s environment.
Arguments
name- The name of the variable to add.var- The variable contents to add.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn default_exec_params(&self) -> ExecutionParameters
pub fn default_exec_params(&self) -> ExecutionParameters
Returns the default execution parameters for this shell.
Sourcepub async fn source_script<S: Into<String>, P: AsRef<Path>, I: Iterator<Item = S>>(
&mut self,
path: P,
args: I,
params: &ExecutionParameters,
) -> Result<ExecutionResult, Error>
pub async fn source_script<S: Into<String>, P: AsRef<Path>, I: Iterator<Item = S>>( &mut self, path: P, args: I, params: &ExecutionParameters, ) -> Result<ExecutionResult, Error>
Source the given file as a shell script, returning the execution result.
Arguments
path- The path to the file to source.args- The arguments to pass to the script as positional parameters.params- Execution parameters.
Sourcepub async fn run_string<S: Into<String>>(
&mut self,
command: S,
source_info: &SourceInfo,
params: &ExecutionParameters,
) -> Result<ExecutionResult, Error>
pub async fn run_string<S: Into<String>>( &mut self, command: S, source_info: &SourceInfo, params: &ExecutionParameters, ) -> Result<ExecutionResult, Error>
Executes the given string as a shell program, returning the resulting exit status.
Arguments
command- The command to execute.source_info- Information about the source of the command text.params- Execution parameters.
Sourcepub async fn run_dash_c_command<S: Into<String>>(
&mut self,
command: S,
) -> Result<ExecutionResult, Error>
pub async fn run_dash_c_command<S: Into<String>>( &mut self, command: S, ) -> Result<ExecutionResult, Error>
Executes the given command, provided to a shell executable on the command
line (i.e., via -c).
It is expected that the shell will not be used for any further execution after this command; this function will perform any necessary shell exit handling.
Arguments
command- The command to execute.
Sourcepub async fn run_script<S: Into<String>, P: AsRef<Path>, I: Iterator<Item = S>>(
&mut self,
script_path: P,
args: I,
) -> Result<ExecutionResult, Error>
pub async fn run_script<S: Into<String>, P: AsRef<Path>, I: Iterator<Item = S>>( &mut self, script_path: P, args: I, ) -> Result<ExecutionResult, Error>
Executes the given script file, returning the resulting exit status.
It is expected that the shell will not be used for any further execution after this command; this function will perform any necessary shell exit handling.
Arguments
script_path- The path to the script file to execute.args- The arguments to pass to the script as positional parameters.
Sourcepub async fn run_program(
&mut self,
program: Program,
params: &ExecutionParameters,
) -> Result<ExecutionResult, Error>
pub async fn run_program( &mut self, program: Program, params: &ExecutionParameters, ) -> Result<ExecutionResult, Error>
Executes the given parsed shell program, returning the resulting exit status.
Arguments
program- The program to execute.params- Execution parameters.
Sourcepub fn eval_arithmetic(&mut self, expr: &ArithmeticExpr) -> Result<i64, Error>
pub fn eval_arithmetic(&mut self, expr: &ArithmeticExpr) -> Result<i64, Error>
Evaluate the given arithmetic expression, returning the result.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn ifs(&self) -> Cow<'_, str>
pub fn ifs(&self) -> Cow<'_, str>
Returns the current value of the IFS variable, or the default value if it is not set.
Sourcepub async fn basic_expand_string<S: AsRef<str>>(
&mut self,
params: &ExecutionParameters,
s: S,
) -> Result<String, Error>
pub async fn basic_expand_string<S: AsRef<str>>( &mut self, params: &ExecutionParameters, s: S, ) -> Result<String, Error>
Sourcepub async fn full_expand_and_split_string<S: AsRef<str>>(
&mut self,
params: &ExecutionParameters,
s: S,
) -> Result<Vec<String>, Error>
pub async fn full_expand_and_split_string<S: AsRef<str>>( &mut self, params: &ExecutionParameters, s: S, ) -> Result<Vec<String>, Error>
Applies full shell expansion and field splitting to the provided string; returns a sequence of fields.
Arguments
s- The string to expand and split.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn set_working_dir(
&mut self,
target_dir: impl AsRef<Path>,
) -> Result<(), Error>
pub fn set_working_dir( &mut self, target_dir: impl AsRef<Path>, ) -> Result<(), Error>
Sets the shell’s current working directory to the given path.
Arguments
target_dir- The path to set as the working directory.
Sourcepub fn tilde_shorten(&self, s: String) -> String
pub fn tilde_shorten(&self, s: String) -> String
Tilde-shortens the given string, replacing the user’s home directory with a tilde.
Arguments
s- The string to shorten.
Sourcepub fn find_executables_in_path<'a>(
&'a self,
filename: &'a str,
) -> impl Iterator<Item = PathBuf> + 'a
pub fn find_executables_in_path<'a>( &'a self, filename: &'a str, ) -> impl Iterator<Item = PathBuf> + 'a
Finds executables in the shell’s current default PATH, matching the given glob pattern.
Arguments
required_glob_pattern- The glob pattern to match against.
Sourcepub fn find_executables_in_path_with_prefix(
&self,
filename_prefix: &str,
case_insensitive: bool,
) -> impl Iterator<Item = PathBuf>
pub fn find_executables_in_path_with_prefix( &self, filename_prefix: &str, case_insensitive: bool, ) -> impl Iterator<Item = PathBuf>
Finds executables in the shell’s current default PATH, with filenames matching the given prefix.
Arguments
filename_prefix- The prefix to match against executable filenames.
Sourcepub fn find_first_executable_in_path<S: AsRef<str>>(
&self,
candidate_name: S,
) -> Option<PathBuf>
pub fn find_first_executable_in_path<S: AsRef<str>>( &self, candidate_name: S, ) -> Option<PathBuf>
Determines whether the given filename is the name of an executable in one of the directories in the shell’s current PATH. If found, returns the path.
Arguments
candidate_name- The name of the file to look for.
Sourcepub fn find_first_executable_in_path_using_cache<S: AsRef<str>>(
&mut self,
candidate_name: S,
) -> Option<PathBuf>
pub fn find_first_executable_in_path_using_cache<S: AsRef<str>>( &mut self, candidate_name: S, ) -> Option<PathBuf>
Uses the shell’s hash-based path cache to check whether the given filename is the name of an executable in one of the directories in the shell’s current PATH. If found, ensures the path is in the cache and returns it.
Arguments
candidate_name- The name of the file to look for.
Sourcepub fn absolute_path(&self, path: impl AsRef<Path>) -> PathBuf
pub fn absolute_path(&self, path: impl AsRef<Path>) -> PathBuf
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub const fn funcs(&self) -> &FunctionEnv
pub const fn funcs(&self) -> &FunctionEnv
Returns the function definition environment for this shell.
Sourcepub const fn funcs_mut(&mut self) -> &mut FunctionEnv
pub const fn funcs_mut(&mut self) -> &mut FunctionEnv
Returns a mutable reference to the function definition environment for this shell.
Sourcepub fn undefine_func(&mut self, name: &str) -> bool
pub fn undefine_func(&mut self, name: &str) -> bool
Tries to undefine a function in the shell’s environment. Returns whether or not a definition was removed.
Arguments
name- The name of the function to undefine.
Sourcepub fn define_func(
&mut self,
name: impl Into<String>,
definition: FunctionDefinition,
source_info: &SourceInfo,
)
pub fn define_func( &mut self, name: impl Into<String>, definition: FunctionDefinition, source_info: &SourceInfo, )
Defines a function in the shell’s environment. If a function already exists with the given name, it is replaced with the new definition.
Arguments
name- The name of the function to define.definition- The function’s definition.source_info- Source information for the function definition.
Sourcepub fn func_mut(&mut self, name: &str) -> Option<&mut Registration>
pub fn func_mut(&mut self, name: &str) -> Option<&mut Registration>
Tries to return a mutable reference to the registration for a named function.
Returns None if no such function was found.
Arguments
name- The name of the function to lookup
Sourcepub fn define_func_from_str(
&mut self,
name: impl Into<String>,
body_text: &str,
) -> Result<(), Error>
pub fn define_func_from_str( &mut self, name: impl Into<String>, body_text: &str, ) -> Result<(), Error>
Tries to define a function in the shell’s environment using the given string as its body.
Arguments
name- The name of the functionbody_text- The body of the function, expected to start with “()”.
Sourcepub async fn invoke_function<N: AsRef<str>, I: IntoIterator<Item = A>, A: AsRef<str>>(
&mut self,
name: N,
args: I,
params: &ExecutionParameters,
) -> Result<u8, Error>
pub async fn invoke_function<N: AsRef<str>, I: IntoIterator<Item = A>, A: AsRef<str>>( &mut self, name: N, args: I, params: &ExecutionParameters, ) -> Result<u8, Error>
Invokes a function defined in this shell, returning the resulting exit status.
Arguments
name- The name of the function to invoke.args- The arguments to pass to the function.params- Execution parameters to use for the invocation.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn history_file_path(&self) -> Option<PathBuf>
pub fn history_file_path(&self) -> Option<PathBuf>
Returns the path to the history file used by the shell, if one is set.
Sourcepub fn history_time_format(&self) -> Option<String>
pub fn history_time_format(&self) -> Option<String>
Returns the path to the history file used by the shell, if one is set.
Sourcepub fn save_history(&mut self) -> Result<(), Error>
pub fn save_history(&mut self) -> Result<(), Error>
Saves history back to any backing storage.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub async fn load_config(
&mut self,
profile_behavior: &ProfileLoadBehavior,
rc_behavior: &RcLoadBehavior,
) -> Result<(), Error>
pub async fn load_config( &mut self, profile_behavior: &ProfileLoadBehavior, rc_behavior: &RcLoadBehavior, ) -> Result<(), Error>
Loads and executes standard shell configuration files (i.e., rc and profile).
Arguments
profile_behavior- Behavior for loading profile files.rc_behavior- Behavior for loading rc files.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn stdout(&self) -> impl Write + 'static
pub fn stdout(&self) -> impl Write + 'static
Returns a value that can be used to write to the shell’s currently configured
standard output stream using write! et al.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn check_for_completed_jobs(&mut self) -> Result<(), Error>
pub fn check_for_completed_jobs(&mut self) -> Result<(), Error>
Checks for completed jobs in the shell, reporting any changes found.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn parse<R: Read>(&self, reader: R) -> Result<Program, ParseError>
pub fn parse<R: Read>(&self, reader: R) -> Result<Program, ParseError>
Parses the given reader as a shell program, returning the resulting Abstract Syntax Tree for the program.
Sourcepub fn parse_string<S: Into<String>>(&self, s: S) -> Result<Program, ParseError>
pub fn parse_string<S: Into<String>>(&self, s: S) -> Result<Program, ParseError>
Parses the given string as a shell program, returning the resulting Abstract Syntax Tree for the program.
Arguments
s- The string to parse as a program.
Sourcepub const fn parser_options(&self) -> ParserOptions
pub const fn parser_options(&self) -> ParserOptions
Returns the options that should be used for parsing shell programs; reflects the current configuration state of the shell and may change over time.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub async fn compose_precmd_prompt(&mut self) -> Result<String, Error>
pub async fn compose_precmd_prompt(&mut self) -> Result<String, Error>
Composes the shell’s post-input, pre-command prompt, applying all appropriate expansions.
Sourcepub async fn compose_prompt(&mut self) -> Result<String, Error>
pub async fn compose_prompt(&mut self) -> Result<String, Error>
Composes the shell’s prompt, applying all appropriate expansions.
Sourcepub async fn compose_alt_side_prompt(&mut self) -> Result<String, Error>
pub async fn compose_alt_side_prompt(&mut self) -> Result<String, Error>
Composes the shell’s alternate-side prompt, applying all appropriate expansions.
Sourcepub async fn compose_continuation_prompt(&mut self) -> Result<String, Error>
pub async fn compose_continuation_prompt(&mut self) -> Result<String, Error>
Composes the shell’s continuation prompt.
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn increment_interactive_line_offset(&mut self, delta: usize)
pub fn increment_interactive_line_offset(&mut self, delta: usize)
Increments the interactive line offset in the shell by the indicated number of lines.
Arguments
delta- The number of lines to increment the current line offset by.
Sourcepub fn set_current_cmd(&mut self, cmd: &impl Node)
pub fn set_current_cmd(&mut self, cmd: &impl Node)
Updates the currently executing command in the shell.
Sourcepub const fn apply_errexit_if_enabled(&self, result: &mut ExecutionResult)
pub const fn apply_errexit_if_enabled(&self, result: &mut ExecutionResult)
Applies errexit semantics to a result if enabled and appropriate. This should be called at “statement boundaries” where errexit should be checked.
Arguments
result- The execution result to potentially modify.
Sourcepub fn is_keyword(&self, s: &str) -> bool
pub fn is_keyword(&self, s: &str) -> bool
Sourceimpl<SE: ShellExtensions> Shell<SE>
impl<SE: ShellExtensions> Shell<SE>
Sourcepub fn is_subshell(&self) -> bool
pub fn is_subshell(&self) -> bool
Returns whether or not this shell is a subshell.
Sourcepub fn last_stopwatch_time(&self) -> SystemTime
pub fn last_stopwatch_time(&self) -> SystemTime
Returns the last “SECONDS” captured time.
Sourcepub fn last_stopwatch_offset(&self) -> u32
pub fn last_stopwatch_offset(&self) -> u32
Returns the last “SECONDS” offset requested.
Sourcepub fn env(&self) -> &ShellEnvironment
pub fn env(&self) -> &ShellEnvironment
Returns the shell environment containing variables.
Sourcepub fn env_mut(&mut self) -> &mut ShellEnvironment
pub fn env_mut(&mut self) -> &mut ShellEnvironment
Returns a mutable reference to the shell environment.
Sourcepub fn options(&self) -> &RuntimeOptions
pub fn options(&self) -> &RuntimeOptions
Returns the shell’s runtime options.
Sourcepub fn options_mut(&mut self) -> &mut RuntimeOptions
pub fn options_mut(&mut self) -> &mut RuntimeOptions
Returns a mutable reference to the shell’s runtime options.
Sourcepub fn aliases_mut(&mut self) -> &mut HashMap<String, String>
pub fn aliases_mut(&mut self) -> &mut HashMap<String, String>
Returns a mutable reference to the shell’s aliases.
Sourcepub fn jobs(&self) -> &JobManager
pub fn jobs(&self) -> &JobManager
Returns the shell’s job manager.
Sourcepub fn jobs_mut(&mut self) -> &mut JobManager
pub fn jobs_mut(&mut self) -> &mut JobManager
Returns a mutable reference to the shell’s job manager.
Sourcepub fn traps(&self) -> &TrapHandlerConfig
pub fn traps(&self) -> &TrapHandlerConfig
Returns the shell’s trap handler configuration.
Sourcepub fn traps_mut(&mut self) -> &mut TrapHandlerConfig
pub fn traps_mut(&mut self) -> &mut TrapHandlerConfig
Returns a mutable reference to the shell’s trap handler configuration.
Sourcepub fn directory_stack(&self) -> &[PathBuf]
pub fn directory_stack(&self) -> &[PathBuf]
Returns the shell’s directory stack.
Sourcepub fn directory_stack_mut(&mut self) -> &mut Vec<PathBuf>
pub fn directory_stack_mut(&mut self) -> &mut Vec<PathBuf>
Returns a mutable reference to the shell’s directory stack.
Sourcepub fn last_pipeline_statuses(&self) -> &[u8] ⓘ
pub fn last_pipeline_statuses(&self) -> &[u8] ⓘ
Returns the statuses of commands in the last pipeline.
Sourcepub fn last_pipeline_statuses_mut(&mut self) -> &mut Vec<u8> ⓘ
pub fn last_pipeline_statuses_mut(&mut self) -> &mut Vec<u8> ⓘ
Returns a mutable reference to the statuses of commands in the last pipeline.
Sourcepub fn program_location_cache(&self) -> &PathCache
pub fn program_location_cache(&self) -> &PathCache
Returns the shell’s program location cache.
Sourcepub fn program_location_cache_mut(&mut self) -> &mut PathCache
pub fn program_location_cache_mut(&mut self) -> &mut PathCache
Returns a mutable reference to the shell’s program location cache.
Sourcepub fn completion_config(&self) -> &Config
pub fn completion_config(&self) -> &Config
Returns the shell’s completion configuration.
Sourcepub fn completion_config_mut(&mut self) -> &mut Config
pub fn completion_config_mut(&mut self) -> &mut Config
Returns a mutable reference to the shell’s completion configuration.
Sourcepub fn open_files(&self) -> &OpenFiles
pub fn open_files(&self) -> &OpenFiles
Returns the shell’s open files.
Sourcepub fn open_files_mut(&mut self) -> &mut OpenFiles
pub fn open_files_mut(&mut self) -> &mut OpenFiles
Returns a mutable reference to the shell’s open files.
Sourcepub fn current_shell_name(&self) -> Option<Cow<'_, str>>
pub fn current_shell_name(&self) -> Option<Cow<'_, str>>
Returns the current name of the shell ($0). Influenced by the current call stack.
Sourcepub fn depth(&self) -> usize
pub fn depth(&self) -> usize
Returns the current subshell depth; 0 is returned if this shell is not a subshell.
Sourcepub fn call_stack(&self) -> &CallStack
pub fn call_stack(&self) -> &CallStack
Returns the call stack for the shell.
Sourcepub fn history_mut(&mut self) -> Option<&mut History>
pub fn history_mut(&mut self) -> Option<&mut History>
Returns a mutable reference to the shell’s history, if it exists.
Sourcepub fn version(&self) -> Option<&str>
pub fn version(&self) -> Option<&str>
Returns the shell’s official version string (if available).
Sourcepub fn last_exit_status(&self) -> u8
pub fn last_exit_status(&self) -> u8
Returns the exit status of the last command executed in this shell.
Sourcepub fn set_last_exit_status(&mut self, status: u8)
pub fn set_last_exit_status(&mut self, status: u8)
Updates the last exit status.
Sourcepub fn key_bindings(&self) -> Option<&Arc<Mutex<dyn KeyBindings>>>
pub fn key_bindings(&self) -> Option<&Arc<Mutex<dyn KeyBindings>>>
Returns the key bindings helper for the shell.
Sourcepub fn set_key_bindings(
&mut self,
key_bindings: Option<Arc<Mutex<dyn KeyBindings>>>,
)
pub fn set_key_bindings( &mut self, key_bindings: Option<Arc<Mutex<dyn KeyBindings>>>, )
Sets the key bindings helper for the shell.
Sourcepub fn working_dir(&self) -> &Path
pub fn working_dir(&self) -> &Path
Returns the shell’s current working directory.
Sourcepub fn product_display_str(&self) -> Option<&str>
pub fn product_display_str(&self) -> Option<&str>
Returns the product display name for this shell.